==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Alati za Blokove</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Prikaži alate za blokove</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Blok</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>Praznine na početku ili na kraju.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Naziv bloka je prazan.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Naziv bloka nije valjan.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Blok već postoji.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Podaci o Bloku</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Naziv bloka:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>blok 1</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Alati za Blokove</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Prikaži alate za blokove</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Blok</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>Praznine na početku ili na kraju.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Naziv bloka je prazan.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Naziv bloka nije valjan.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Blok već postoji.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Podaci o Bloku</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Naziv bloka:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>blok 1</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="obsolete">Praznine na početku ili na kraju.</translation>
    </message>
</context>
</TS>
